@@ -33,3 +33,13 @@ def parse_task():
     namespace: ap.Namespace = arg_parser.parse_args()
     print(namespace)
     # execute_task(opt.action.task_name)
+
+
+def do_task():
+    try:
+        import tasks as t
+    except ModuleNotFoundError:
+        print("No tasks directory")
+        return
+
+    parse_task()
